@@ -43,7 +43,10 @@ SUBJECTS_DIR = SAMPLE_PATH / 'SUBJECTS_DIR'
 IO_PATH = SAMPLE_PATH / 'io'
 ktlx_file = IO_PATH / 'xltek'
 mff_file = IO_PATH / 'egi.mff'
+nev_file = IO_PATH / 'blackrock' / 'blackrock.nev'
 ns2_file = IO_PATH / 'blackrock' / 'blackrock.ns2'
+ns4_file = IO_PATH / 'blackrock' / 'sampleData.ns4'
+hdf5_file = IO_PATH / 'fieldtrip_hdf5.mat'
 
 # Folder where to export data
 EXPORTED_PATH = test_path / 'exported'
@@ -51,14 +54,19 @@ EXPORTED_PATH.mkdir(exist_ok=True)
 annot_file = EXPORTED_PATH / 'annot_scores.xml'
 annot_export_file = EXPORTED_PATH / 'annot_scores.csv'
 annot_fasst_export_file = EXPORTED_PATH / 'annot_fasst.xml'
+annot_sleepstats_path = EXPORTED_PATH / 'annot_sleepstats.csv'
 exported_chan_path = EXPORTED_PATH / 'grid_chan.sfp'
 channel_montage_file = EXPORTED_PATH / 'channel_montage.json'
 channel_montage_reref_file = EXPORTED_PATH / 'channel_montage_reref.json'
+fieldtrip_file = EXPORTED_PATH / 'fieldtrip.mat'
 wonambi_file = EXPORTED_PATH / 'exported.won'
 
 # Store images
 DOCS_PATH = test_path.parent / 'docs'
-GUI_PATH = DOCS_PATH / 'source' / 'gui' / 'images'
+SOURCE_PATH = DOCS_PATH / 'source'
+GUI_PATH = SOURCE_PATH / 'gui' / 'images'
 GUI_PATH.mkdir(exist_ok=True)
-VIZ_PATH = DOCS_PATH / 'source' / 'viz' / 'images'
+VIZ_PATH = SOURCE_PATH / 'analysis' / 'images'
 VIZ_PATH.mkdir(exist_ok=True)
+PLOTLY_PATH = SOURCE_PATH / 'analysis' / 'plotly'
+PLOTLY_PATH.mkdir(exist_ok=True)
