@@ -18,6 +18,8 @@ from .paths import (annot_file,
                     annot_fasst_path,
                     annot_remlogic_path,
                     annot_sandman_path,
+                    annot_psg_path,
+                    annot_sleepstats_path,
                     ns2_file,
                     )
 
@@ -108,7 +110,16 @@ def test_events():
     assert len(annot.event_types) == 1
     assert len(annot.get_events()) == 0
     
+def test_epochs():
+    d = Dataset(ns2_file)
+    create_empty_annotations(annot_file, d)
+
+    annot = Annotations(annot_file)
+    annot.add_rater('test')
     
+    assert len(annot.get_epochs()) == 50
+    assert len(annot.get_epochs(time=(1000,2000))) == 16
+        
 def test_import_alice():
     annot = Annotations(annot_file)
     record_start = datetime(2000, 1, 1, 22, 55, 6)
@@ -154,3 +165,7 @@ def test_import_fasst_error():
     with raises(UnrecognizedFormat):
         create_annotation(annot_fasst_export_file,
                           from_fasst=ns2_file)
+        
+def test_export_sleepstats():
+    annot = Annotations(annot_psg_path)
+    assert annot.export_sleep_stats(annot_sleepstats_path, 0, 29000) == 338
