@@ -5,7 +5,8 @@ from bisect import bisect_left
 from csv import writer
 from datetime import datetime, timedelta
 from itertools import compress
-from numpy import allclose, asarray, in1d, isnan, logical_and, modf
+from numpy import (allclose, around, asarray, in1d, isnan, logical_and, modf,
+                   nan)
 from math import ceil, inf
 from os.path import splitext
 from pathlib import Path
@@ -242,6 +243,11 @@ class Annotations():
     def raters(self):
         return [rater.get('name') for rater in self.root.iter('rater')]
 
+    @property
+    def epoch_length(self):
+        epoch = next(self.epochs)
+        return around(epoch['end'] - epoch['start'])
+
     def get_rater(self, rater_name):
         # get xml root for one rater
         found = False
@@ -298,7 +304,7 @@ class Annotations():
 
         self.save()
 
-    def import_staging(self, filename, source, rater_name, rec_start, 
+    def import_staging(self, filename, source, rater_name, rec_start,
                        staging_start=None):
         """Import staging from a SomnoMedics Domino staging text file.
 
@@ -313,10 +319,10 @@ class Annotations():
             Rater name for imported staging.
         rec_start : datetime
             Date and time (year, month, day, hour, minute, second) of recording
-            start. Year is ignored (New Year's Eve celebratory recordings 
+            start. Year is ignored (New Year's Eve celebratory recordings
             unsupported.)
         staging_start : datetime (default: None)
-            Date and time of staging start. For use when not provided in 
+            Date and time of staging start. For use when not provided in
             staging file.
         """
         if rater_name not in self.raters:
@@ -328,7 +334,7 @@ class Annotations():
         # list is necessary so that it does not remove in place
         for s in list(stages):
             stages.remove(s)
-        
+
         if source == 'sandman':
             encoding = 'ISO-8859-1'
         else:
@@ -337,79 +343,79 @@ class Annotations():
         with open(filename, 'r', encoding=encoding) as f:
             lines = f.readlines()
             stages = self.rater.find('stages')
-                        
-            if source == 'domino':            
+
+            if source == 'domino':
                 stage_start = datetime.strptime(lines[7][:8], '%H:%M:%S')
                 stage_day = int(lines[1][12:14])
                 stage_month = int(lines[1][15:17])
-                stage_start_for_delta = stage_start.replace(year=1999, 
+                stage_start_for_delta = stage_start.replace(year=1999,
                                                             month=stage_month,
                                                             day=stage_day)
                 rec_start_for_delta = rec_start.replace(year=1999)
-                first_second = int((stage_start_for_delta - 
+                first_second = int((stage_start_for_delta -
                                     rec_start_for_delta).total_seconds())
-                
+
                 first_line = 7
-                
+
                 stage_key = DOMINO_STAGE_KEY
                 idx_stage = (14, 16)
-            
+
             elif source == 'remlogic':
                 stage_start = datetime.strptime(lines[14][:19],
                                                 '%Y-%m-%dT%H:%M:%S')
                 first_second = int((stage_start - rec_start).total_seconds())
-                
+
                 first_line = 14
-                
+
                 stage_key = REMLOGIC_STAGE_KEY
                 idx_stage = (-6, -4)
-            
+
             elif source == 'alice':
                 stage_start = datetime.strptime(lines[1][2:13], '%I:%M:%S %p')
                 dt = rec_start
-                
-                if lines[1][11:13] == 'pm' and rec_start.hour < 12: 
+
+                if lines[1][11:13] == 'pm' and rec_start.hour < 12:
                     # best guess in absence of date
                     dt = rec_start - timedelta(days=1)
-                    
+
                 stage_start = stage_start.replace(year=dt.year,
                                                   month=dt.month,
-                                                  day=dt.day)                                    
+                                                  day=dt.day)
                 first_second = int((stage_start - rec_start).total_seconds())
-                
+
                 first_line = 1
-                
+
                 lines[-1] += '_' # to fill newline position
                 stage_key = ALICE_STAGE_KEY
                 idx_stage = (-3, -1)
-                
+
             elif source == 'sandman':
-                stage_start = datetime.strptime(lines[4][12:33], 
+                stage_start = datetime.strptime(lines[4][12:33],
                                                 '%d/%m/%Y %I:%M:%S %p')
                 first_second = int((stage_start - rec_start).total_seconds())
-                
+
                 first_line = 14
-                
+
                 stage_key = SANDMAN_STAGE_KEY
                 idx_stage = (-14, -12)
-                
+
             elif source == 'compumedics':
                 if staging_start is None:
                     first_second = 0
                 else:
                     first_second = int((
                             staging_start - rec_start).total_seconds())
-                
+
                 first_line = 0
-                
+
                 stage_key = COMPUMEDICS_STAGE_KEY
                 idx_stage = (0, 1)
-                
+
             else:
                 raise ValueError('Unknown source program for staging file')
-            
+
             lg.info('Time offset: ' + str(first_second) + ' sec')
-                
+
             for i, one_line in enumerate(lines[first_line:]):
                 epoch = SubElement(stages, 'epoch')
 
@@ -421,15 +427,15 @@ class Annotations():
                 end_time.text = str(epoch_beg + 30)
 
                 epoch_stage = SubElement(epoch, 'stage')
-                
+
                 try:
                     key = one_line[idx_stage[0]:idx_stage[1]]
                     one_stage = stage_key[key]
-                    
+
                 except KeyError:
                     one_stage = 'Unknown'
                     lg.info('Stage not recognized: ' + key)
-                    
+
                 epoch_stage.text = one_stage
 
                 quality = SubElement(epoch, 'quality')
@@ -751,16 +757,6 @@ class Annotations():
                 else:
                     ev_qual = ep_quality[pos]
                     qual_cond = ev_qual == qual
-                """
-                if stage is None:
-                    stage_cond = True
-                else:
-                    if event_start == ep_starts[pos]:
-                        ev_stage = ep_stages[pos]
-                    else:
-                        ev_stage = ep_stages[pos - 1]
-                    stage_cond = ev_stage in stage
-                """
 
                 if time is None:
                     time_cond = True
@@ -795,7 +791,7 @@ class Annotations():
         first_second : int, optional
             Time, in seconds from record start, at which the epochs begin
         """
-        lg.info('creating epochs')        
+        lg.info('creating epochs of length ' + str(epoch_length))
         if first_second is None:
             first_second = self.first_second
         last_sec = ceil((self.last_second - first_second) /
@@ -825,7 +821,8 @@ class Annotations():
         -------
         list of dict
             each epoch is defined by start_time and end_time (in s in reference
-            to the start of the recordings) and a string of the sleep stage.
+            to the start of the recordings) and a string of the sleep stage,
+            and a string of the signal quality.
             If you specify stages_of_interest, only epochs belonging to those
             stages will be included (can be an empty list).
 
@@ -845,6 +842,47 @@ class Annotations():
                      }
             yield epoch
 
+    def get_epochs(self, time=None, stage=None, qual=None,
+                   chan=None, name=None):
+        """Get list of events in the file.
+
+        Parameters
+        ----------
+        time : tuple of two float, optional
+            start and end time of the period of interest
+        chan : tuple of str, optional
+            list of channels of interests
+        stage : tuple of str, optional
+            list of stages of interest
+        qual : str, optional
+            epoch signal qualifier (Good or Poor)
+        chan : None
+            placeholder, to maintain format similar to get_events
+        name : None
+            placeholder, to maintain format similar to get_events
+        Returns
+        -------
+        list of dict
+            where each dict has 'start' (start time), 'end' (end time),
+            'stage', 'qual' (signal quality)
+        """
+        time_cond = True
+        stage_cond = True
+        qual_cond = True
+        valid = []
+
+        for ep in self.epochs:
+            if stage:
+                stage_cond = ep['stage'] in stage
+            if qual:
+                qual_cond = ep['quality'] == qual
+            if time:
+                time_cond = time[0] <= ep['start'] and time[1] >= ep['end']
+            if stage_cond and qual_cond and time_cond:
+                valid.append(ep)
+
+        return valid
+
     def get_epoch_start(self, window_start):
         """ Get the position (seconds) of the nearest epoch.
 
@@ -863,7 +901,8 @@ class Annotations():
 
         return epoch_starts[idx]
 
-    def get_stage_for_epoch(self, epoch_start, window_length, attr='stage'):
+    def get_stage_for_epoch(self, epoch_start, window_length=None,
+                            attr='stage'):
         """Return stage for one specific epoch.
 
         Parameters
@@ -877,15 +916,17 @@ class Annotations():
         -------
         stage : str
             description of the stage.
-
         """
-
         for epoch in self.epochs:
             if epoch['start'] == epoch_start:
                 return epoch[attr]
-            elif logical_and(window_length < 30, 
-                             0 <= (epoch_start - epoch['start']) < 30):
-                return epoch[attr]
+
+            if window_length is not None:
+                epoch_length = epoch['end'] - epoch['start']
+                if logical_and(window_length < epoch_length,
+                               0 <= \
+                               (epoch_start - epoch['start']) < epoch_length):
+                    return epoch[attr]
 
     def time_in_stage(self, name, attr='stage'):
         """Return time (in seconds) in the selected stage.
@@ -1019,7 +1060,7 @@ class Annotations():
 
         Returns
         -------
-        list of tuple
+        list of tuple of float
             start and end times for each cycle, in seconds from recording start
         """
         cycles = self.rater.find('cycles')
@@ -1029,7 +1070,7 @@ class Annotations():
 
         starts = [float(mrkr.text) for mrkr in cycles.findall('cyc_start')]
         ends = [float(mrkr.text) for mrkr in cycles.findall('cyc_end')]
-        output = []
+        cyc_list = []
 
         if not starts or not ends:
             return None
@@ -1055,7 +1096,12 @@ class Annotations():
             if one_cycle[1] == inf:
                 raise ValueError('Last cycle has no end.')
 
-            output.append(one_cycle)
+            cyc_list.append(one_cycle)
+
+        output = []
+        for i, j in enumerate(cyc_list):
+            cyc = j[0], j[1], i + 1
+            output.append(cyc)
 
         return output
 
@@ -1084,6 +1130,102 @@ class Annotations():
                                        epoch['end'],
                                        epoch['stage']))
 
+    def export_sleep_stats(self, filename, lights_out, lights_on):
+        """Create CSV with sleep statistics.
+
+        Parameters
+        ----------
+        filename: str
+            Filename for csv export
+        lights_out: float
+            Initial time when sleeper turns off the light (or their phone) to
+            go to sleep, in seconds from recording start.
+        lights_on: float
+            Final time when sleeper rises from bed after sleep, in seconds from
+            recording start.
+
+        Returns
+        -------
+        float or None
+            If there are no epochs scored as sleep, returns None. Otherwise,
+            returns the sleep onset latency, for testing purposes.
+        """
+        epochs = self.get_epochs()
+        hypno = [i['stage'] for i in epochs]
+
+        first = {}
+        latency = {}
+        for stage in ['NREM1', 'NREM2', 'NREM3', 'REM']:
+            first[stage] = next(((i, j) for i, j in enumerate(epochs) if \
+                                j['stage'] == stage), None)
+            if first[stage] is not None:
+                latency[stage] = (first[stage][1]['start'] - lights_out) / 60
+            else:
+                latency[stage] = nan
+                del first[stage]
+
+        if first == {}:
+            return None
+
+        duration = {}
+        for stage in ['NREM1', 'NREM2', 'NREM3', 'REM', 'Wake', 'Movement',
+                      'Artefact']:
+            duration[stage] = hypno.count(stage) * self.epoch_length / 60
+
+        slp_onset = sorted(first.values(), key=lambda x: x[1]['start'])[0]
+        wake_up = next((len(epochs) - i, j) for i, j in enumerate(epochs[::-1]) if \
+                       j['stage'] in ['NREM1', 'NREM2', 'NREM3', 'REM'])
+
+        total_dark_time = (lights_on - lights_out) / 60
+        slp_period_time = (wake_up[1]['start'] - slp_onset[1]['start']) / 60
+        slp_onset_lat = (slp_onset[1]['start'] - lights_out) / 60
+        waso = (hypno[slp_onset[0]:wake_up[0]].count('Wake') *
+                self.epoch_length) / 60
+        total_slp_time = slp_period_time - waso
+        slp_eff = total_slp_time / total_dark_time
+
+        with open(filename, 'w', newline='') as f:
+            lg.info('Writing to' + str(filename))
+            csv_file = writer(f)
+            csv_file.writerow(['Total dark time',
+                               'Sleep onset latency',
+                               'Sleep period time',
+                               'WASO',
+                               'Total sleep time',
+                               'Sleep efficiency',
+                               'N1 latency',
+                               'N2 latency',
+                               'N3 latency',
+                               'REM latency',
+                               'N1 duration',
+                               'N2 duration',
+                               'N3 duration',
+                               'REM duration',
+                               'Wake duration',
+                               'Movement duration',
+                               'Artefact duration',
+                               ])
+            csv_file.writerow([total_dark_time,
+                               slp_onset_lat,
+                               slp_period_time,
+                               waso,
+                               total_slp_time,
+                               slp_eff,
+                               latency['NREM1'],
+                               latency['NREM2'],
+                               latency['NREM3'],
+                               latency['REM'],
+                               duration['NREM1'],
+                               duration['NREM2'],
+                               duration['NREM3'],
+                               duration['REM'],
+                               duration['Wake'],
+                               duration['Movement'],
+                               duration['Artefact'],
+                               ])
+
+        return slp_onset_lat # for testing
+
     def export_event_data(self, filename, summary, events, cycles=None,
                           fsplit=None):
         """Export event analysis data to CSV, from dialog.
@@ -1136,7 +1278,8 @@ class Annotations():
         per_evt_params = list(compress(ordered_params[:-2], idx_params))
 
         lg.info('sheets: ' + str(len(sheets)) + ' summ: ' + str(len(summary)) + 'events: ' + str(len(events)))
-        lg.info('number of events ' + str(len(events[0])))
+        if events is not None:
+            lg.info('number of events ' + str(len(events[0])))
 
         for fn, summ, evs in zip(sheets, summary, events):
             first_row = list(compress(headings, idx_params))
