@@ -2,13 +2,21 @@
 
 """
 from logging import getLogger
-from numpy import argmax, concatenate, hstack, sum, zeros
+from numpy import (argmax, argmin, concatenate, diff, hstack, sign, sum, where,
+                   zeros)
 
-from .spindle import detect_events, transform_signal, within_duration
+try:
+    from PyQt5.QtCore import Qt
+    from PyQt5.QtWidgets import QProgressDialog
+except ImportError:
+    pass
+
+from .spindle import (detect_events, transform_signal, within_duration, 
+                      remove_straddlers)
 from ..graphoelement import SlowWaves
 
 lg = getLogger(__name__)
-MAXIMUM_DURATION = 10
+MAXIMUM_DURATION = 5
 
 
 class DetectSlowWave:
@@ -25,11 +33,7 @@ class DetectSlowWave:
     """
     def __init__(self, method='Massimini2004', duration=None):
 
-        if duration is None:
-            duration = (0.5, 3)
-
         self.method = method
-        self.duration = duration
 
         if method == 'Massimini2004':
             self.det_filt = {'order': 3,
@@ -37,6 +41,8 @@ class DetectSlowWave:
             self.trough_duration = (0.3, 1.)
             self.max_trough_amp = - 80
             self.min_ptp = 140
+            self.min_dur = 0
+            self.max_dur = None
             self.invert = False
 
         elif method == 'AASM/Massimini2004':
@@ -45,33 +51,52 @@ class DetectSlowWave:
             self.trough_duration = (0.25, 1.)
             self.max_trough_amp = - 40
             self.min_ptp = 75
+            self.min_dur = 0
+            self.max_dur = None
             self.invert = False
 
         else:
             raise ValueError('Unknown method')
+            
+        if duration is None:
+            self.duration = (self.min_dur, self.max_dur)
+        
+        else:
+            self.duration = duration
 
     def __repr__(self):
-        return ('detsw_{0}_{1:04.2f}-{2:04.2f}Hz_{3:04.2f}-{4:04.2f}s'
-                ''.format(self.method, *self.det_filt['freq'], *self.duration))
+        return ('detsw_{0}_{1:04.2f}-{2:04.2f}Hz'
+                ''.format(self.method, *self.det_filt['freq']))
 
-    def __call__(self, data):
+    def __call__(self, data, parent=None):
         """Detect slow waves on the data.
 
         Parameters
         ----------
         data : instance of Data
             data used for detection
-
+        parent : QWidget
+            for use with GUI, as parent widget for the progress bar
+        
         Returns
         -------
         instance of graphoelement.SlowWaves
             description of the detected SWs
         """
+        if parent is not None:
+            progress = QProgressDialog('Finding spindles', 'Abort', 
+                                       0, data.number_of('chan')[0], parent)
+            progress.setWindowModality(Qt.ApplicationModal)
+            
         slowwave = SlowWaves()
         slowwave.chan_name = data.axis['chan'][0]
 
         all_slowwaves = []
         for i, chan in enumerate(data.axis['chan'][0]):
+            
+            if parent is not None:
+                progress.setValue(i)
+            
             lg.info('Detecting slow waves on chan %s', chan)
             time = hstack(data.axis['time'])
             dat_orig = hstack(data(chan=chan))
@@ -91,6 +116,9 @@ class DetectSlowWave:
         lg.info('number of SW: ' + str(len(all_slowwaves)))
         slowwave.events = sorted(all_slowwaves, key=lambda x: x['start'])
 
+        if parent is not None:
+            progress.setValue(i + 1)
+
         return slowwave
 
 def detect_Massimini2004(dat_orig, s_freq, time, opts):
@@ -129,7 +157,8 @@ def detect_Massimini2004(dat_orig, s_freq, time, opts):
     if opts.invert:
         dat_orig = -dat_orig
 
-    dat_det = transform_signal(dat_orig, s_freq, 'butter', opts.det_filt)
+    dat_det = transform_signal(dat_orig, s_freq, 'double_butter', 
+                               opts.det_filt)
     below_zero = detect_events(dat_det, 'below_thresh', value=0.)
 
     sw_in_chan = []
@@ -147,6 +176,7 @@ def detect_Massimini2004(dat_orig, s_freq, time, opts):
 
                 if len(events):
                     events = within_duration(events, time, opts.duration)
+                    events = remove_straddlers(events, time, s_freq)
                     lg.info('SWs within duration: ' + str(events.shape))
 
                     sw_in_chan = make_slow_waves(events, dat_det, time, s_freq)
@@ -246,28 +276,36 @@ def _add_pos_halfwave(data, events, s_freq, opts):
         samples
     """
     max_dur = opts.duration[1]
-
     if max_dur is None:
         max_dur = MAXIMUM_DURATION
+    
     window = int(s_freq * max_dur)
+    lg.info('window: ' + str(window))
 
     peak_and_end = zeros((events.shape[0], 2), dtype='int')
     events = concatenate((events, peak_and_end), axis=1)
     selected = []
 
     for ev in events:
-        ev[4] = ev[2] + argmax(data[ev[2]:ev[0] + window] < 0)  # quickest way
-
-        if ev[2] == ev[4]:
+        zero_crossings = where(diff(sign(data[ev[2]:ev[0] + window])))[0]
+        
+        if zero_crossings.any():
+            ev[4] = ev[2] + zero_crossings[0] + 1
+            lg.info('0cross is at ' + str(ev[4]))
+            
+        else:
             selected.append(False)
+            lg.info('no 0cross, rejected')
             continue
 
-        ev[3] = argmax(data[ev[2]:ev[4]])
+        ev[3] = ev[2] + argmax(data[ev[2]:ev[4]])
 
         if abs(data[ev[1]] - data[ev[3]]) < opts.min_ptp:
             selected.append(False)
+            lg.info('ptp too low, rejected: ' + str(abs(data[ev[1]] - data[ev[3]])))
             continue
 
         selected.append(True)
+        lg.info('SW checks out, ACCEPTED! ptp is ' + str(abs(data[ev[1]] - data[ev[3]])))
 
     return events[selected, :]
