@@ -2,18 +2,23 @@
 """
 from logging import getLogger
 from numpy import (absolute, arange, argmax, argmin, asarray, concatenate, cos,
-                   diff, exp, empty, floor, hstack, insert, invert, linspace,
-                   mean, median, nan, ones, pi, ptp, sqrt, square,
-                   std, vstack, where, zeros)
+                   diff, exp, empty, floor, hstack, insert, invert,
+                   logical_and, mean, median, nan, ones, pi, ptp, real, sqrt, 
+                   square, std, vstack, where, zeros)
 from scipy.ndimage.filters import gaussian_filter
 from scipy.signal import (argrelmax, butter, cheby2, filtfilt, fftconvolve,
                           hilbert, periodogram, tukey)
+try:
+    from PyQt5.QtCore import Qt
+    from PyQt5.QtWidgets import QProgressDialog
+except ImportError:
+    pass
 
 from ..graphoelement import Spindles
 
 lg = getLogger(__name__)
 MAX_FREQUENCY_OF_INTEREST = 50
-MAX_DURATION = 5
+MAX_DURATION = 10
 
 
 class DetectSpindle:
@@ -31,61 +36,62 @@ class DetectSpindle:
     def __init__(self, method='Moelle2011', frequency=None, duration=None,
                  merge=True):
 
-        if frequency is None:
-            frequency = (11, 18)
-        if duration is None:
-            duration = (0.5, 2)
-
         self.method = method
-        self.frequency = frequency
-        self.duration = duration
         self.merge = merge
         self.min_interval = 0
-
+        self.det_thresh_hi = 0
         self.power_peaks = 'interval'
 
         if method == 'Ferrarelli2007':
-            self.det_butter = {'order': 4,
+            self.frequency = (12, 15)
+            self.det_butter = {'order': 3,
                                'freq': self.frequency,
                                }
+            self.duration = (0.3, None)
             self.det_wavelet = {'sd': None}
-            self.det_thresh = 8
+            self.det_thresh_lo = 8
             self.sel_thresh = 2
             self.moving_rms = {'dur': None}
             self.smooth = {'dur': None}
 
         elif method == 'Nir2011':
-            self.det_butter = {'order': 4,
+            self.frequency = (10, 16)
+            self.det_butter = {'order': 2,
                                'freq': self.frequency,
                                }
+            self.duration = (0.5, 2)
             self.det_wavelet = {'sd': None}
-            self.det_thresh = 3
+            self.det_thresh_lo = 3
             self.sel_thresh = 1
             self.min_interval = 1
             self.moving_rms = {'dur': None}
-            self.smooth = {'dur': .4}  # is in fact sigma
+            self.smooth = {'dur': .04}  # is in fact sigma
 
         elif method == 'Wamsley2012':
+            self.frequency = (12, 15)
             self.det_wavelet = {'f0': mean(self.frequency),
                                 'sd': .5,
                                 'dur': 2,
                                 }
-            self.det_thresh = 4.5
+            self.duration = (0.3, 3)
+            self.det_thresh_lo = 4.5
             self.sel_thresh = None  # necessary for gui/detect
             self.moving_rms = {'dur': None}
             self.smooth = {'dur': .1}
 
         elif method == 'UCSD':
-            self.det_wavelet = {'freqs': arange(frequency[0],
-                                                frequency[1] + .5, .5),
+            self.frequency = (10, 16)
+            self.det_wavelet = {'freqs': arange(self.frequency[0],
+                                                self.frequency[1] + .5, .5),
                                 'dur': 1,
                                 'width': .5,
                                 'win': .5,
                                 'sd': None
                                 }
-            self.det_thresh = 2  # wavelet_peak_thresh
-            self.sel_wavelet = {'freqs': arange(frequency[0],
-                                                frequency[1] + .5, .5),
+            self.duration = (0.3, 3)
+            self.det_thresh_lo = 2  # wavelet_peak_thresh
+            self.sel_wavelet = {'freqs': arange(self.frequency[0],
+                                                self.frequency[1] + .5, .5),
                                 'dur': 1,
                                 'width': .2,
                                 'win': .2,
@@ -96,51 +102,89 @@ class DetectSpindle:
             self.smooth = {'dur': None}
 
         elif method == 'Moelle2011':
-            self.det_butter = {'order': 4,
+            self.frequency = (9, 15)
+            self.det_butter = {'order': 3,
                                'freq': self.frequency,
                                }
+            self.duration = (0.5, 3)
             self.det_wavelet = {'sd': None}
-            self.det_thresh = 1.5
+            self.det_thresh_lo = 1.5
             self.sel_thresh = None
             self.moving_rms = {'dur': .2}
             self.smooth = {'dur': .2}
 
+        elif method == 'Concordia':
+            self.frequency = (10, 16)
+            self.det_butter = {'order': 3,
+                               'freq': self.frequency,
+                               }
+            self.duration = (0.5, 3)
+            self.det_wavelet = {'sd': None}
+            self.det_thresh_lo = 1.5
+            self.det_thresh_hi = 10
+            self.sel_thresh = 1
+            self.moving_rms = {'dur': .2}
+            self.smooth = {'dur': .2}
+            self.min_interval = 0.2
+
         else:
             raise ValueError('Unknown method')
+            
+        if frequency is not None:
+            self.frequency = frequency  
+            
+        if duration is not None:
+            self.duration = duration
 
     def __repr__(self):
         return ('detsp_{0}_{1:02}-{2:02}Hz_{3:04.1f}-{4:04.1f}s'
                 ''.format(self.method, self.frequency[0], self.frequency[1],
                           self.duration[0], self.duration[1]))
 
-    def __call__(self, data):
+    def __call__(self, data, parent=None):
         """Detect spindles on the data.
 
         Parameters
         ----------
         data : instance of Data
             data used for detection
+        parent : QWidget
+            for use with GUI, as parent widget for the progress bar
 
         Returns
         -------
         instance of graphoelement.Spindles
             description of the detected spindles
         """
+        if parent is not None:
+            progress = QProgressDialog('Finding spindles', 'Abort', 
+                                       0, data.number_of('chan')[0], parent)
+            progress.setWindowModality(Qt.ApplicationModal)
+        
         spindle = Spindles()
         spindle.chan_name = data.axis['chan'][0]
-        spindle.det_value = zeros(data.number_of('chan')[0])
+        spindle.det_value_lo = zeros(data.number_of('chan')[0])
+        spindle.det_value_hi = zeros(data.number_of('chan')[0])
         spindle.sel_value = zeros(data.number_of('chan')[0])
         spindle.density = zeros(data.number_of('chan')[0])
+        
+        if self.duration[1] is None:
+            self.duration = self.duration[0], MAX_DURATION
 
         all_spindles = []
         for i, chan in enumerate(data.axis['chan'][0]):
+            
+            if parent is not None:
+                progress.setValue(i)
+                
             lg.info('Detecting spindles on chan %s', chan)
             time = hstack(data.axis['time'])
             dat_orig = hstack(data(chan=chan))
 
             if self.method == 'Ferrarelli2007':
                 sp_in_chan, values, density = detect_Ferrarelli2007(dat_orig,
-                                                                    data.s_freq, time,
+                                                                    data.s_freq,
+                                                                    time,
                                                                     self)
 
             elif self.method == 'Nir2011':
@@ -161,10 +205,15 @@ class DetectSpindle:
                 sp_in_chan, values, density = detect_Moelle2011(dat_orig,
                                                                 data.s_freq,
                                                                 time, self)
+            elif self.method == 'Concordia':
+                sp_in_chan, values, density = detect_Concordia(dat_orig,
+                                                               data.s_freq,
+                                                               time, self)
             else:
                 raise ValueError('Unknown method')
 
-            spindle.det_value[i] = values['det_value']
+            spindle.det_value_lo[i] = values['det_value_lo']
+            spindle.det_value_hi[i] = values['det_value_hi']
             spindle.sel_value[i] = values['sel_value']
             spindle.density[i] = density
 
@@ -179,6 +228,9 @@ class DetectSpindle:
         if self.merge and len(data.axis['chan'][0]) > 1:
             spindle.events = merge_close(spindle.events, self.min_interval)
 
+        if parent is not None:
+            progress.setValue(i + 1)
+        
         return spindle
 
 
@@ -208,7 +260,8 @@ def detect_Ferrarelli2007(dat_orig, s_freq, time, opts):
     list of dict
         list of detected spindles
     dict
-        'det_value' with detection value, 'sel_value' with selection value
+        'det_value_lo' with detection value, 'det_value_hi' with nan,
+        'sel_value' with selection value
     float
         spindle density, per 30-s epoch
 
@@ -222,10 +275,9 @@ def detect_Ferrarelli2007(dat_orig, s_freq, time, opts):
     Ferrarelli, F. et al. Am. J. Psychiatry 164, 483-92 (2007).
     """
     dat_det = transform_signal(dat_orig, s_freq, 'butter', opts.det_butter)
-    dat_det = transform_signal(dat_det, s_freq, 'hilbert')
     dat_det = transform_signal(dat_det, s_freq, 'abs')
 
-    det_value = define_threshold(dat_det, s_freq, 'mean', opts.det_thresh)
+    det_value = define_threshold(dat_det, s_freq, 'mean', opts.det_thresh_lo)
     sel_value = define_threshold(dat_det, s_freq, 'mean', opts.sel_thresh)
 
     events = detect_events(dat_det, 'above_thresh', det_value)
@@ -234,8 +286,8 @@ def detect_Ferrarelli2007(dat_orig, s_freq, time, opts):
         events = select_events(dat_det, events, 'above_thresh', sel_value)
 
         events = _merge_close(dat_det, events, time, opts.min_interval)
-
-        events = within_duration(events, time, opts.duration)
+        events = within_duration(events, time, opts.duration)        
+        events = remove_straddlers(events, time, s_freq)
 
         power_peaks = peak_in_power(events, dat_orig, s_freq, opts.power_peaks)
         power_avgs = avg_power(events, dat_orig, s_freq, opts.frequency)
@@ -246,8 +298,8 @@ def detect_Ferrarelli2007(dat_orig, s_freq, time, opts):
         lg.info('No spindle found')
         sp_in_chan = []
 
-    values = {'det_value': det_value, 'sel_value': sel_value}
-    lg.info(str(values))
+    values = {'det_value_lo': det_value, 'det_value_hi': nan,
+              'sel_value': sel_value}
 
     density = len(sp_in_chan) * s_freq * 30 / len(dat_orig)
 
@@ -282,7 +334,8 @@ def detect_Moelle2011(dat_orig, s_freq, time, opts):
     list of dict
         list of detected spindles
     dict
-        'det_value' with detection value, 'sel_value' with nan
+        'det_value_lo' with detection value, 'det_value_hi' with nan,
+        'sel_value' with nan
     float
         spindle density, per 30-s epoch
 
@@ -299,14 +352,15 @@ def detect_Moelle2011(dat_orig, s_freq, time, opts):
     dat_det = transform_signal(dat_det, s_freq, 'moving_rms', opts.moving_rms)
     dat_det = transform_signal(dat_det, s_freq, 'moving_avg', opts.smooth)
 
-    det_value = define_threshold(dat_det, s_freq, 'mean+std', opts.det_thresh)
+    det_value = define_threshold(dat_det, s_freq, 'mean+std',
+                                 opts.det_thresh_lo)
 
     events = detect_events(dat_det, 'above_thresh', det_value)
 
     if events is not None:
         events = _merge_close(dat_det, events, time, opts.min_interval)
-
         events = within_duration(events, time, opts.duration)
+        events = remove_straddlers(events, time, s_freq)
 
         power_peaks = peak_in_power(events, dat_orig, s_freq, opts.power_peaks)
         power_avgs = avg_power(events, dat_orig, s_freq, opts.frequency)
@@ -317,7 +371,7 @@ def detect_Moelle2011(dat_orig, s_freq, time, opts):
         lg.info('No spindle found')
         sp_in_chan = []
 
-    values = {'det_value': det_value, 'sel_value': nan}
+    values = {'det_value_lo': det_value, 'det_value_hi': nan, 'sel_value': nan}
 
     density = len(sp_in_chan) * s_freq * 30 / len(dat_orig)
 
@@ -354,7 +408,8 @@ def detect_Nir2011(dat_orig, s_freq, time, opts):
     list of dict
         list of detected spindles
     dict
-        'det_value' with detection value, 'sel_value' with selection value
+        'det_value_lo' with detection value, 'det_value_hi' with nan,
+        'sel_value' with selection value
     float
         spindle density, per 30-s epoch
 
@@ -377,17 +432,19 @@ def detect_Nir2011(dat_orig, s_freq, time, opts):
     dat_det = transform_signal(dat_det, s_freq, 'abs')
     dat_det = transform_signal(dat_det, s_freq, 'gaussian', opts.smooth)
 
-    det_value = define_threshold(dat_det, s_freq, 'mean+std', opts.det_thresh)
+    det_value = define_threshold(dat_det, s_freq, 'mean+std',
+                                 opts.det_thresh_lo)
     sel_value = define_threshold(dat_det, s_freq, 'mean+std', opts.sel_thresh)
 
     events = detect_events(dat_det, 'above_thresh', det_value)
 
     if events is not None:
-        events = select_events(dat_det, events, 'above_thresh', sel_value)
-
         events = _merge_close(dat_det, events, time, opts.min_interval)
 
+        events = select_events(dat_det, events, 'above_thresh', sel_value)
+
         events = within_duration(events, time, opts.duration)
+        events = remove_straddlers(events, time, s_freq)
 
         power_peaks = peak_in_power(events, dat_orig, s_freq, opts.power_peaks)
         power_avgs = avg_power(events, dat_orig, s_freq, opts.frequency)
@@ -398,7 +455,8 @@ def detect_Nir2011(dat_orig, s_freq, time, opts):
         lg.info('No spindle found')
         sp_in_chan = []
 
-    values = {'det_value': det_value, 'sel_value': sel_value}
+    values = {'det_value_lo': det_value, 'det_value_hi': nan,
+              'sel_value': sel_value}
 
     density = len(sp_in_chan) * s_freq * 30 / len(dat_orig)
 
@@ -433,8 +491,8 @@ def detect_Wamsley2012(dat_orig, s_freq, time, opts):
     list of dict
         list of detected spindles
     dict
-        'det_value' with detection value, 'sel_value' is nan (for consistency
-        with other methods)
+        'det_value_lo' with detection value, 'det_value_hi' is nan,
+        'sel_value' is nan (for consistency with other methods)
     float
         spindle density, per 30-s epoch
 
@@ -443,16 +501,17 @@ def detect_Wamsley2012(dat_orig, s_freq, time, opts):
     Wamsley, E. J. et al. Biol. Psychiatry 71, 154-61 (2012).
     """
     dat_det = transform_signal(dat_orig, s_freq, 'morlet', opts.det_wavelet)
+    dat_det = real(dat_det ** 2) ** 2
     dat_det = transform_signal(dat_det, s_freq, 'moving_avg', opts.smooth)
 
-    det_value = define_threshold(dat_det, s_freq, 'mean', opts.det_thresh)
+    det_value = define_threshold(dat_det, s_freq, 'mean', opts.det_thresh_lo)
 
     events = detect_events(dat_det, 'above_thresh', det_value)
 
     if events is not None:
         events = _merge_close(dat_det, events, time, opts.min_interval)
-
         events = within_duration(events, time, opts.duration)
+        events = remove_straddlers(events, time, s_freq)
 
         power_peaks = peak_in_power(events, dat_orig, s_freq, opts.power_peaks)
         power_avgs = avg_power(events, dat_orig, s_freq, opts.frequency)
@@ -463,7 +522,7 @@ def detect_Wamsley2012(dat_orig, s_freq, time, opts):
         lg.info('No spindle found')
         sp_in_chan = []
 
-    values = {'det_value': det_value, 'sel_value': nan}
+    values = {'det_value_lo': det_value, 'det_value_hi': nan, 'sel_value': nan}
 
     density = len(sp_in_chan) * s_freq * 30 / len(dat_orig)
 
@@ -500,7 +559,8 @@ def detect_UCSD(dat_orig, s_freq, time, opts):
     list of dict
         list of detected spindles
     dict
-        'det_value' with detection value, 'sel_value' is selection value
+        'det_value_lo' with detection value, 'det_value_hi' with nan,
+        'sel_value' with selection value
     float
         spindle density, per 30-s epoch
 
@@ -509,7 +569,7 @@ def detect_UCSD(dat_orig, s_freq, time, opts):
                                opts.det_wavelet)
 
     det_value = define_threshold(dat_det, s_freq, 'median+std',
-                                 opts.det_thresh)
+                                 opts.det_thresh_lo)
 
     events = detect_events(dat_det, 'maxima', det_value)
 
@@ -520,8 +580,8 @@ def detect_UCSD(dat_orig, s_freq, time, opts):
     events = select_events(dat_sel, events, 'above_thresh', sel_value)
 
     events = _merge_close(dat_det, events, time, opts.min_interval)
-
     events = within_duration(events, time, opts.duration)
+    events = remove_straddlers(events, time, s_freq)
 
     events = power_ratio(events, dat_orig, s_freq, opts.frequency,
                          opts.ratio_thresh)
@@ -531,7 +591,82 @@ def detect_UCSD(dat_orig, s_freq, time, opts):
     sp_in_chan = make_spindles(events, power_peaks, power_avgs, dat_det,
                                dat_orig, time, s_freq)
 
-    values = {'det_value': det_value, 'sel_value': sel_value}
+    values = {'det_value_lo': det_value, 'det_value_hi': nan,
+              'sel_value': sel_value}
+
+    density = len(sp_in_chan) * s_freq * 30 / len(dat_orig)
+
+    return sp_in_chan, values, density
+
+
+def detect_Concordia(dat_orig, s_freq, time, opts):
+    """Spindle detection, experimental Concordia method. Similar to Moelle 2011
+    and Nir2011.
+
+    Parameters
+    ----------
+    dat_orig : ndarray (dtype='float')
+        vector with the data for one channel
+    s_freq : float
+        sampling frequency
+    opts : instance of 'DetectSpindle'
+        'det_butter' : dict
+            parameters for 'butter',
+        'moving_rms' : dict
+            parameters for 'moving_rms'
+        'smooth' : dict
+            parameters for 'moving_avg'
+        'det_thresh_lo' : float
+            low detection threshold
+        'det_thresh_hi' : float
+            high detection threshold
+        'sel_thresh' : float
+            selection threshold
+        'duration' : tuple of float
+            min and max duration of spindles
+
+    Returns
+    -------
+    list of dict
+        list of detected spindles
+    dict
+        'det_value_lo', 'det_value_hi' with detection values, 'sel_value' with
+        selection value
+    float
+        spindle density, per 30-s epoch
+    """
+    dat_det = transform_signal(dat_orig, s_freq, 'butter', opts.det_butter)
+    dat_det = transform_signal(dat_det, s_freq, 'moving_rms', opts.moving_rms)
+    dat_det = transform_signal(dat_det, s_freq, 'moving_avg', opts.smooth)
+
+    det_value_lo = define_threshold(dat_det, s_freq, 'mean+std',
+                                    opts.det_thresh_lo)
+    det_value_hi = define_threshold(dat_det, s_freq, 'mean+std',
+                                    opts.det_thresh_hi)
+    sel_value = define_threshold(dat_det, s_freq, 'mean+std', opts.sel_thresh)
+
+    events = detect_events(dat_det, 'between_thresh',
+                           value=(det_value_lo, det_value_hi))
+
+    if events is not None:
+        events = _merge_close(dat_det, events, time, opts.min_interval)
+
+        events = select_events(dat_det, events, 'above_thresh', sel_value)
+
+        events = within_duration(events, time, opts.duration)
+        events = remove_straddlers(events, time, s_freq)
+
+        power_peaks = peak_in_power(events, dat_orig, s_freq, opts.power_peaks)
+        power_avgs = avg_power(events, dat_orig, s_freq, opts.frequency)
+        sp_in_chan = make_spindles(events, power_peaks, power_avgs, dat_det,
+                                   dat_orig, time, s_freq)
+
+    else:
+        lg.info('No spindle found')
+        sp_in_chan = []
+
+    values = {'det_value_lo': det_value_lo, 'det_value_hi': det_value_hi,
+              'sel_value': sel_value}
 
     density = len(sp_in_chan) * s_freq * 30 / len(dat_orig)
 
@@ -560,6 +695,9 @@ def transform_signal(dat, s_freq, method, method_opt=None):
 
     Notes
     -----
+    double_butter implements an effective bandpass by applying a highpass, 
+    followed by a lowpass. This method reduces filter instability, due to 
+    underlying numerical instability arising from nyquist / freq, at low freq.
     Wavelets pass only absolute values already, it does not make sense to store
     the complex values.
 
@@ -573,7 +711,13 @@ def transform_signal(dat, s_freq, method, method_opt=None):
 
     butter has parameters:
         freq : tuple of float
-            high and low values for bandpass
+            low and high values for bandpass
+        order : int
+            filter order
+            
+    double_butter has parameters:
+        freq : tuple of float
+            low and high values for highpass, then lowpass
         order : int
             filter order
 
@@ -624,9 +768,23 @@ def transform_signal(dat, s_freq, method, method_opt=None):
         nyquist = s_freq / 2
         Wn = asarray(freq) / nyquist
         b, a = butter(N, Wn, btype='bandpass')
-        lg.info('butter: a='+str(a)+' b='+str(b)+' Wn='+str(Wn)+' N='+str(N) + ' freq: ' + str(freq))
         dat = filtfilt(b, a, dat)
 
+    if 'double_butter' == method:
+        freq = method_opt['freq']
+        N = method_opt['order']
+        nyquist = s_freq / 2
+        
+        # Highpass
+        Wn = freq[0] / nyquist
+        b, a = butter(N, Wn, btype='highpass')
+        dat = filtfilt(b, a, dat)
+        
+        # Lowpass
+        Wn = freq[1] / nyquist
+        b, a = butter(N, Wn, btype='lowpass')
+        dat = filtfilt(b, a, dat)
+    
     if 'morlet' == method:
         f0 = method_opt['f0']
         sd = method_opt['sd']
@@ -722,8 +880,10 @@ def detect_events(dat, method, value=None):
         vector with the data after transformation
     method : str
         'above_thresh', 'below_thresh' or 'maxima'
-    value : float
-        for 'threshold's, it's the value of threshold for the event detection
+    value : float or tuple of float
+        for 'above_thresh' or 'below_thresh', it's the value of threshold for
+        the event detection
+        for 'between_thresh', it's the lower and upper threshold as tuple
         for 'maxima', it's the distance in s from the peak to find a minimum
 
     Returns
@@ -732,30 +892,36 @@ def detect_events(dat, method, value=None):
         N x 3 matrix with start, peak, end samples
 
     """
-    if method == 'above_thresh':
-        above_det = dat >= value
-        detected = _detect_start_end(above_det)
-        
+    if 'thresh' in method:
+
+        if method == 'above_thresh':
+            above_det = dat >= value
+            detected = _detect_start_end(above_det)
+
+        if method == 'below_thresh':
+            below_det = dat < value
+            detected = _detect_start_end(below_det)
+
+        if method == 'between_thresh':
+            above_det = dat >= value[0]
+            below_det = dat < value[1]
+            between_det = logical_and(above_det, below_det)
+            detected = _detect_start_end(between_det)
+
         if detected is None:
             return None
-
-        # add the location of the peak in the middle
-        detected = insert(detected, 1, 0, axis=1)
-        for i in detected:
-            i[1] = i[0] + argmax(dat[i[0]:i[2]])
-
-    if method == 'below_thresh':
-        below_det = dat < value
-        detected = _detect_start_end(below_det)
         
-        if detected is None:
-            return None
+        if method == 'above_thresh':    
+            # add the location of the peak in the middle
+            detected = insert(detected, 1, 0, axis=1)
+            for i in detected:
+                i[1] = i[0] + argmax(dat[i[0]:i[2]])
 
-        # add the location of the trough in the middle
-        detected = insert(detected, 1, 0, axis=1)
-        for i in detected:
-            i[1] = i[0] + argmin(dat[i[0]:i[2]])
-        #lg.info('troughs values: ' + str(dat[detected[:,1]]))
+        if method in ['below_thresh', 'between_thresh']:
+            # add the location of the trough in the middle
+            detected = insert(detected, 1, 0, axis=1)
+            for i in detected:
+                i[1] = i[0] + argmin(dat[i[0]:i[2]])
 
     if method == 'maxima':
         peaks = argrelmax(dat)[0]
@@ -834,7 +1000,7 @@ def merge_close(events, min_interval, merge_to_longer=False):
                     start = min(lower['start'], higher['start'])
                     higher.update({'start': start})
                     merged[-1] = higher
-                        
+
                 else:
                     end = max(lower['end'], higher['end'])
                     merged[-1].update({'end': end})
@@ -862,12 +1028,44 @@ def within_duration(events, time, limits):
     ndarray (dtype='int')
         N x 3 matrix with start , peak, end samples
     """
-    min_dur = time[events[:, 2] - 1] - time[events[:, 0]] >= limits[0]
-    max_dur = time[events[:, 2] - 1] - time[events[:, 0]] <= limits[1]
+    min_dur = max_dur = ones(events.shape[0], dtype=bool)
+    
+    if limits[0] is not None:
+        min_dur = time[events[:, 2] - 1] - time[events[:, 0]] >= limits[0]
+    
+    if limits[1] is not None:
+        max_dur = time[events[:, 2] - 1] - time[events[:, 0]] <= limits[1]
 
     return events[min_dur & max_dur, :]
 
 
+def remove_straddlers(events, time, s_freq, toler=0.1):
+    """Reject an event if it straddles a cision point, by comparing its 
+    duration to its timespan
+
+    Parameters
+    ----------
+    events : ndarray (dtype='int')
+        N x 3 matrix with start, peak, end samples
+    time : ndarray (dtype='float')
+        vector with time points
+    s_freq : float
+        sampling frequency
+    toler : float, def=0.1
+        maximum tolerated difference between event duration and timespan
+
+    Returns
+    -------
+    ndarray (dtype='int')
+        N x 3 matrix with start , peak, end samples
+    """
+    duration = (events[:, 2] - 1 - events[:, 0]) / s_freq
+    continuous = time[events[:, 2] - 1] - time[events[:, 0]] - duration < toler
+    
+    return events[continuous, :]
+    
+
+
 def power_ratio(events, dat, s_freq, limits, ratio_thresh):
     """Estimate the ratio in power between spindle band and lower frequencies.
 
@@ -1206,7 +1404,7 @@ def _merge_close(dat, events, time, min_interval):
 
         new_events = vstack((begs, ends)).T
     else:
-        new_events = asarray[[events[0, 0], events[-1, 2]]]
+        new_events = asarray([[events[0, 0], events[-1, 2]]])
 
     # add the location of the peak in the middle
     new_events = insert(new_events, 1, 0, axis=1)
