@@ -10,8 +10,6 @@ from .moberg import Moberg
 from .mnefiff import write_mnefiff
 from .fieldtrip import FieldTrip, write_fieldtrip
 from .wonambi import Wonambi, write_wonambi
-from .ieeg_org import IEEG_org
-from .opbox import OpBox
 from .micromed import Micromed
 from .bci2000 import BCI2000
-# from .eeglab import Eeglab, write_eeglab
+from .text import Text
