@@ -1,6 +1,7 @@
 """Package containing additional functions and classes, such as:
     - exceptions
+    - simulate (functions to create fake data, channels for testing purposes)
 
 """
 from .exceptions import UnrecognizedFormat
-from .simulate import create_data
+from .simulate import create_data, create_channels
