@@ -2,6 +2,7 @@
 """
 from copy import deepcopy
 from json import dump, load
+from logging import getLogger
 from os.path import splitext
 
 from PyQt5.QtGui import (QColor,
@@ -29,6 +30,8 @@ from PyQt5.QtWidgets import (QAbstractItemView,
 
 from .settings import Config, FormFloat, FormStr
 
+lg = getLogger(__name__)
+
 
 class ConfigChannels(Config):
     """Widget with preferences in Settings window for Channels."""
@@ -112,14 +115,20 @@ class ChannelsGroup(QWidget):
         self.add_channels_to_list(self.idx_l1)
 
         self.idx_hp = QDoubleSpinBox()
-        self.idx_hp.setValue(config_value['hp'])
+        hp = config_value['hp']
+        if hp is None:
+            hp = 0
+        self.idx_hp.setValue(hp)
         self.idx_hp.setSuffix(' Hz')
         self.idx_hp.setDecimals(1)
         self.idx_hp.setMaximum(s_freq / 2)
         self.idx_hp.setToolTip('0 means no filter')
 
         self.idx_lp = QDoubleSpinBox()
-        self.idx_lp.setValue(config_value['lp'])
+        lp = config_value['lp']
+        if lp is None:
+            lp = 0
+        self.idx_lp.setValue(lp)
         self.idx_lp.setSuffix(' Hz')
         self.idx_lp.setDecimals(1)
         self.idx_lp.setMaximum(s_freq / 2)
@@ -360,7 +369,9 @@ class Channels(QWidget):
         """
         chan_name = self.parent.labels.chan_name
         if chan_name is None:
-            self.parent.statusBar().showMessage('No dataset loaded')
+            msg = 'No dataset loaded'
+            self.parent.statusBar().showMessage(msg)
+            lg.debug(msg)
 
         else:
             if test_name is None:
@@ -417,9 +428,11 @@ class Channels(QWidget):
         if self.groups:
             self.parent.overview.update_position()
             self.parent.spectrum.update()
+            self.parent.notes.enable_events()
         else:
             self.parent.traces.reset()
             self.parent.spectrum.reset()
+            self.parent.notes.enable_events()
 
     def read_group_info(self):
         """Get information about groups directly from the widget."""
@@ -477,8 +490,9 @@ class Channels(QWidget):
             self.tabs.addTab(group, one_grp['name'])
 
         if no_in_dataset:
-            msg = 'Channels not present in the dataset: '
-            self.parent.statusBar().showMessage(msg + ', '.join(no_in_dataset))
+            msg = 'Channels not present in the dataset: ' + ', '.join(no_in_dataset)
+            self.parent.statusBar().showMessage(msg)
+            lg.debug(msg)
 
         self.apply()
 
