@@ -16,11 +16,11 @@ from .settings import (Settings, SlowWaveHelp, SpindleHelp,
 from .utils import ICON  # has to be second
 from .labels import Labels
 from .channels import Channels
-from .info import Info
+from .info import Info, ExportDatasetDialog
 from .overview import Overview
 from .notes import (Notes, MergeDialog, SpindleDialog, SWDialog,
                     EventAnalysisDialog)
-from .analysis import AnalysisDialog
+from .analysis import AnalysisDialog, PlotDialog
 from .spectrum import Spectrum
 from .traces import Traces
 from .video import Video
@@ -39,6 +39,7 @@ def create_widgets(MAIN):
     MAIN.channels = Channels(MAIN)
     MAIN.notes = Notes(MAIN)
     MAIN.merge_dialog = MergeDialog(MAIN)
+    MAIN.export_dataset_dialog = ExportDatasetDialog(MAIN)
     MAIN.spindle_dialog = SpindleDialog(MAIN)
     MAIN.slow_wave_dialog = SWDialog(MAIN)
     MAIN.spindle_help = SpindleHelp(MAIN)
@@ -46,6 +47,7 @@ def create_widgets(MAIN):
     MAIN.event_analysis_dialog = EventAnalysisDialog(MAIN)
     MAIN.evt_analysis_help = EvtAnalysisHelp(MAIN)
     MAIN.analysis_dialog = AnalysisDialog(MAIN)
+    MAIN.plot_dialog = PlotDialog(MAIN)
     MAIN.overview = Overview(MAIN)
     MAIN.spectrum = Spectrum(MAIN)
     MAIN.traces = Traces(MAIN)
@@ -152,6 +154,7 @@ def create_menubar(MAIN):
     menu_file.addAction(MAIN.info.action['open_dataset'])
     submenu_recent = menu_file.addMenu('Recent Datasets')
     submenu_recent.addActions(MAIN.info.action['open_recent'])
+    menu_file.addAction(MAIN.info.action['export'])
 
     menu_file.addSeparator()
     menu_file.addAction(actions['open_settings'])
@@ -272,8 +275,9 @@ def create_menubar(MAIN):
     submenu_detect.addAction(actions['spindle'])
     submenu_detect.addAction(actions['slow_wave'])
 
-    menu_analysis.addAction(actions['analyze_events'])    
+    menu_analysis.addAction(actions['analyze_events'])
     menu_analysis.addAction(actions['analyze'])
+    menu_analysis.addAction(actions['export_sleepstats'])
 
 
     """ ------ WINDOWS ------ """
