@@ -15,6 +15,7 @@ from PyQt5.QtWidgets import (QCheckBox,
                              QLineEdit,
                              QListWidget,
                              QPushButton,
+                             QRadioButton,
                              QSplitter,
                              QStackedWidget,
                              QTextEdit,
@@ -419,7 +420,10 @@ class SpindleHelp(HelpDialog):
              'wavelet with the average of <b>Lowcut</b> and <b>Highcut</b> as '
              'the frequency, with σ = <b>Wavelet sigma</b> [0.5] s and with '
              'window size = <b>Detection window</b> [1] s.</li>'
-             '<li>The moving average of the rectified signal is calculated, '
+             '<li>The resulting complex-valued time series is squared.</li>'
+             '<li>The imaginary part of the time-series is discarded, and the '
+             'remaining real-valued time series is squared again.'
+             '<li>The moving average of the real signal is calculated, '
              'using a sliding window of size = <b>Smoothing</b> [0.1] s.</li>'
              '<li>A spindle event is identified whenever this wavelet signal '
              'exceeds threshold, defined as <b>Detection threshold</b> [4.5] '
@@ -746,6 +750,60 @@ class FormBool(QCheckBox):
         self.stateChanged.connect(funct)
 
 
+class FormRadio(QRadioButton):
+    """Subclass QRadioButton to have a more consistent API across widgets.
+
+    Parameters
+    ----------
+    checkbox_label : str
+        label next to checkbox
+
+    """
+    def __init__(self, checkbox_label):
+        super().__init__(checkbox_label)
+
+    def get_value(self, default=False):
+        """Get the value of the QCheckBox, as boolean.
+
+        Parameters
+        ----------
+        default : bool
+            not used
+
+        Returns
+        -------
+        bool
+            state of the checkbox
+
+        """
+        return self.isChecked  == Qt.Checked
+
+    def set_value(self, value):
+        """Set value of the checkbox.
+
+        Parameters
+        ----------
+        value : bool
+            value for the checkbox
+
+        """
+        if value:
+            self.setCheckState(Qt.Checked)
+        else:
+            self.setCheckState(Qt.Unchecked)
+
+    def connect(self, funct):
+        """Call funct when user ticks the box.
+
+        Parameters
+        ----------
+        funct : function
+            function that broadcasts a change.
+
+        """
+        self.toggled.connect(funct)
+
+
 class FormFloat(QLineEdit):
     """Subclass QLineEdit for float to have a more consistent API across
     widgets.
