@@ -6,8 +6,8 @@ from logging import getLogger
 from re import compile
 
 from numpy import (abs, arange, argmin, around, asarray, ceil, empty, floor,
-                   in1d, max, min, linspace, log2, logical_or, nanmean, pad,
-                   power)
+                   in1d, max, min, linspace, log2, logical_or, nan_to_num,
+                   nanmean, pad, power)
 
 from PyQt5.QtCore import QPointF, Qt, QRectF
 from PyQt5.QtGui import (QBrush,
@@ -18,6 +18,7 @@ from PyQt5.QtGui import (QBrush,
                          QPen,
                          )
 from PyQt5.QtWidgets import (QAction,
+                             QErrorMessage,
                              QFormLayout,
                              QGraphicsItem,
                              QGraphicsRectItem,
@@ -221,7 +222,7 @@ class Traces(QGraphicsView):
         act.setShortcut(QKeySequence.FindNext)
         act.triggered.connect(self.go_to_epoch)
         actions['go_to_epoch'] = act
-        
+
         act = QAction('Line Up with Epoch', self)
         act.triggered.connect(self.line_up_with_epoch)
         actions['line_up_with_epoch'] = act
@@ -314,6 +315,7 @@ class Traces(QGraphicsView):
 
         self.data = _create_data_to_plot(data, self.parent.channels.groups)
 
+
     def display(self):
         """Display the recordings."""
         if self.data is None:
@@ -343,7 +345,7 @@ class Traces(QGraphicsView):
         self.idx_markers = []
         self.idx_annot = []
         self.idx_annot_labels = []
-
+        
         self.add_chan_labels()
         self.add_time_labels()
         self.add_traces()
@@ -422,7 +424,7 @@ class Traces(QGraphicsView):
         self.chan = []
         self.chan_pos = []
         self.chan_scale = []
-
+        
         row = 0
         for one_grp in self.parent.channels.groups:
             for one_chan in one_grp['chan_to_plot']:
@@ -446,7 +448,7 @@ class Traces(QGraphicsView):
                 self.chan.append(chan_name)
                 self.chan_scale.append(one_grp['scale'])
                 self.chan_pos.append(chan_pos)
-
+                
     def display_grid(self):
         """Display grid on x-axis and y-axis."""
         window_start = self.parent.value('window_start')
@@ -578,13 +580,13 @@ class Traces(QGraphicsView):
                     self.scene.addItem(item)
                     self.idx_annot_labels.append(item)
 
-                    item = RectMarker(mrk_start, 0, mrk_end - mrk_start, 
-                                      h_annot, zvalue=-8, 
+                    item = RectMarker(mrk_start, 0, mrk_end - mrk_start,
+                                      h_annot, zvalue=-8,
                                       color=color.lighter(120))
 
                     """
                     item = QGraphicsRectItem(mrk_start + 0.5, 0,
-                                             mrk_end - mrk_start - 1, 
+                                             mrk_end - mrk_start - 1,
                                              h_annot)
                     item.setBrush(color.lighter(120))
                     item.setPen(color.lighter(120))
@@ -600,11 +602,11 @@ class Traces(QGraphicsView):
                     y_annot -= y_distance / 2
 
                     for y in y_annot:
-                        item = RectMarker(mrk_start, y, mrk_end - mrk_start, 
+                        item = RectMarker(mrk_start, y, mrk_end - mrk_start,
                                           y_distance, zvalue=-7, color=color)
                         self.scene.addItem(item)
                         self.idx_annot.append(item)
-                        
+
                         """
                         item = QGraphicsRectItem(mrk_start + 0.5, y,
                                                  mrk_end - mrk_start - 1,
@@ -667,19 +669,28 @@ class Traces(QGraphicsView):
             rec_start_time = self.parent.info.dataset.header['start_time']
             window_start = _convert_timestr_to_seconds(time_str, rec_start_time)
         except ValueError as err:
+            error_dialog = QErrorMessage()
+            error_dialog.setWindowTitle('Error moving to epoch')
+            error_dialog.showMessage(str(err))
+            if test_text_str is None:
+                error_dialog.exec()
             self.parent.statusBar().showMessage(str(err))
             return
+
         self.parent.overview.update_position(window_start)
-        
+
     def line_up_with_epoch(self):
         """Go to the start of the present epoch."""
         if self.parent.notes.annot is None:  # TODO: remove if buttons are disabled
-            self.parent.statusBar().showMessage('No score file loaded')
+            error_dialog = QErrorMessage()
+            error_dialog.setWindowTitle('Error moving to epoch')
+            error_dialog.showMessage('No score file loaded')
+            error_dialog.exec()
             return
-        
+
         new_window_start = self.parent.notes.annot.get_epoch_start(
-                self.parent.value('window_start'))
-        
+            self.parent.value('window_start'))
+
         self.parent.overview.update_position(new_window_start)
 
     def add_time(self, extra_time):
@@ -775,21 +786,25 @@ class Traces(QGraphicsView):
         else:
             for annot in self.idx_annot:
                 if annot.contains(xy_scene):
-                    beg = annot.rect().x() - 0.5
-                    end = beg + annot.rect().width() + 1
+                    beg = annot.marker.x() - 0.5
+                    end = beg + annot.marker.width() + 1
                     msg = 'Event from ' + str(beg) + ' to ' + str(end)
                     self.parent.statusBar().showMessage(msg)
                     self.event_sel = annot
-                    highlight = QGraphicsRectItem(annot.rect().x() - 0.5,
-                                                  annot.rect().y() - 0.5,
-                                                  annot.rect().width() + 1,
-                                                  annot.rect().height() + 1)
-                    pen = QPen(QColor(255, 255, 51), 0, Qt.SolidLine,
-                               Qt.RoundCap)
-                    brush = QBrush(QColor(255, 255, 51))
-                    highlight.setPen(pen)
-                    highlight.setBrush(brush)
-                    highlight.setZValue(-5)
+                    highlight = RectMarker(annot.marker.x(),
+                                           annot.marker.y(),
+                                           annot.marker.width(),
+                                           annot.marker.height(),
+                                           zvalue=-5,
+                                           color=QColor(255, 255, 51))
+#==============================================================================
+#                     pen = QPen(QColor(255, 255, 51), 0, Qt.SolidLine,
+#                                Qt.RoundCap)
+#                     brush = QBrush(QColor(255, 255, 51))
+#                     highlight.setPen(pen)
+#                     highlight.setBrush(brush)
+#                     highlight.setZValue(-5)
+#==============================================================================
                     self.scene.addItem(highlight)
                     self.highlight = highlight
                     break
@@ -825,6 +840,9 @@ class Traces(QGraphicsView):
         if self.event_sel or self.deselect:
             return
 
+        if self.sel_xy[0] is None or self.sel_xy[1] is None:
+            return
+
         if self.idx_sel in self.scene.items():
             self.scene.removeItem(self.idx_sel)
             self.idx_sel = None
@@ -968,8 +986,8 @@ class Traces(QGraphicsView):
 
         annot = self.event_sel
         highlight = self.highlight
-        annot_start = annot.rect().x() - 0.5
-        annot_end = annot_start + annot.rect().width() + 1
+        annot_start = annot.marker.x()
+        annot_end = annot_start + annot.marker.width()
 
         if type(event) == QKeyEvent and (
            event.key() == Qt.Key_Delete or event.key() == Qt.Key_Backspace):
@@ -1063,9 +1081,11 @@ def _create_data_to_plot(data, chan_groups):
                                     one_grp['ref_chan'])
         data1 = montage(sel_data, ref_chan=one_grp['ref_chan'])
 
+        data1.data[0] = nan_to_num(data1.data[0])
+
         if one_grp['hp'] is not None:
             data1 = filter_(data1, low_cut=one_grp['hp'])
-
+        
         if one_grp['lp'] is not None:
             data1 = filter_(data1, high_cut=one_grp['lp'])
 
