@@ -2,6 +2,7 @@
 """
 from logging import getLogger
 from math import ceil, floor
+from numpy import arange
 from os.path import dirname, join, realpath
 
 from PyQt5.QtCore import QRectF, QSettings, Qt
@@ -30,7 +31,8 @@ stdicon = QCommonStyle.standardIcon
 icon_path = join(dirname(realpath(__file__)), 'icons')
 oxy_path = join(icon_path, 'oxygen')
 
-ICON = {'open_rec': join(oxy_path, 'document-open.png'),
+ICON = {'application': join(icon_path, 'wonambi.jpg'),
+        'open_rec': join(oxy_path, 'document-open.png'),
         'page_prev': join(oxy_path, 'go-previous-view.png'),
         'page_next': join(oxy_path, 'go-next-view.png'),
         'step_prev': join(oxy_path, 'go-previous.png'),
@@ -77,7 +79,7 @@ class Path(QPainterPath):
 
 class RectMarker(QGraphicsRectItem):
     """Class to draw a rectangular, coloured item.
-    
+
     Parameters
     ----------
     x : float
@@ -93,23 +95,26 @@ class RectMarker(QGraphicsRectItem):
     """
     def __init__(self, x, y, width, height, zvalue, color='blue'):
         super().__init__()
-        
+
         self.color = color
         self.setZValue(zvalue)
         buffer = 1
         self.marker = QRectF(x, y, width, height)
-        self.b_rect = QRectF(x - buffer/2, y + buffer/2, width + buffer,
+        self.b_rect = QRectF(x - buffer / 2, y + buffer / 2, width + buffer,
                              height + buffer)
 
     def boundingRect(self):
         return self.b_rect
-        
+
     def paint(self, painter, option, widget):
         color = QColor(self.color)
         painter.setBrush(QBrush(color))
         painter.setPen(Qt.NoPen)
         painter.drawRect(self.marker)
         super().paint(painter, option, widget)
+        
+    def contains(self, pos):
+        return self.marker.contains(pos)
 
 
 class TextItem_with_BG(QGraphicsSimpleTextItem):
@@ -155,11 +160,7 @@ def keep_recent_datasets(max_dataset_history, info=None):
         history = [history]
 
     if info is not None and info.filename is not None:
-        if info.repo is not None:
-            # this will parsed by self.info.open_dataset()
-            new_dataset = info.filename + ' (' + info.repo + ')'
-        else:
-            new_dataset = info.filename
+        new_dataset = info.filename
 
         if new_dataset in history:
             lg.debug(new_dataset + ' already present, will be replaced')
@@ -168,7 +169,7 @@ def keep_recent_datasets(max_dataset_history, info=None):
             lg.debug('Removing last dataset ' + history[-1])
             history.pop()
 
-        lg.info('Adding ' + new_dataset + ' to list of recent datasets')
+        lg.debug('Adding ' + new_dataset + ' to list of recent datasets')
         history.insert(0, new_dataset)
         settings.setValue('recent_recordings', history)
         return None
@@ -183,15 +184,13 @@ def choose_file_or_dir():
     Returns
     -------
     str
-        'dir' or 'file' or 'ieegorg' or 'abort'
+        'dir' or 'file' or 'abort'
 
     """
     question = QMessageBox(QMessageBox.Information, 'Open Dataset',
-                           'Do you want to open a file, a directory or a '
-                           'remote ieeg.org dataset?')
+                           'Do you want to open a file or a directory?')
     dir_button = question.addButton('Directory', QMessageBox.YesRole)
     file_button = question.addButton('File', QMessageBox.NoRole)
-    remote_button = question.addButton('Remote Dataset', QMessageBox.NoRole)
     question.addButton(QMessageBox.Cancel)
     question.exec_()
     response = question.clickedButton()
@@ -200,8 +199,6 @@ def choose_file_or_dir():
         return 'dir'
     elif response == file_button:
         return 'file'
-    elif response == remote_button:
-        return 'remote'
     else:
         return 'abort'
 
@@ -246,3 +243,114 @@ def convert_name_to_color(s):
     color = QColor(sum_mod(v[::3]) + h, sum_mod(v[1::3]) + h,
                    sum_mod(v[2::3]) + h)
     return color
+
+
+def remove_artf_evts(times, annot, min_dur=0.5):
+    """Correct times to remove events marked 'Artefact'.
+
+    Parameters
+    ----------
+    times : list of tuple of float
+        the start and end times of each segment
+    annot: instance of Annotations
+        The annotation file containing events and epochs
+
+    Returns
+    -------
+    list of tuple of float
+        the new start and end times of each segment, with artefact periods 
+        taken out            
+    """    
+    new_times = times
+    beg = times[0][0]
+    end = times[-1][-1]
+    
+    artefact = annot.get_events(name='Artefact', time=(beg, end), qual='Good')
+        
+    if artefact:
+        new_times = []
+        
+        for seg in times:
+            reject = False
+            new_seg = True
+            
+            while new_seg is not False:
+                if type(new_seg) is tuple:
+                    seg = new_seg
+                end = seg[1]
+            
+                for artf in artefact:
+                    
+                    if artf['start'] <= seg[0] and seg[1] <= artf['end']:
+                        reject = True
+                        new_seg = False
+                        break
+                    
+                    a_starts_in_s = seg[0] <= artf['start'] <= seg[1]
+                    a_ends_in_s = seg[0] <= artf['end'] <= seg[1]
+                    
+                    if a_ends_in_s and not a_starts_in_s:
+                        seg = artf['end'], seg[1]
+                        
+                    elif a_starts_in_s:
+                        seg = seg[0], artf['start']
+    
+                        if a_ends_in_s:
+                            new_seg = artf['end'], end
+                        else:
+                            new_seg = False
+                        break
+                    
+                    new_seg = False
+            
+                if reject is False and seg[1] - seg[0] >= min_dur:
+                    new_times.append(seg)
+        
+    return new_times 
+
+
+def freq_from_str(freq_str):
+    """Obtain frequency ranges from input string, either as list or dynamic 
+    notation.
+    
+    Parameters
+    ----------
+    freq_str : str
+        String with frequency ranges, either as a list:
+        e.g. [[1-3], [3-5], [5-8]]; 
+        or with a dynamic definition: (start, stop, width, step).
+        
+    Returns
+    -------
+    list of tuple of float or None
+        Every tuple of float represents a frequency band. If input is invalid,
+        returns None.
+    """
+    freq = []
+    as_list = freq_str[1:-1].replace(' ', '').split(',')
+    
+    if freq_str[0] == '[' and freq_str[-1] == ']':
+        for i in as_list:
+            one_band = i[1:-1].split('-')
+            one_band = float(one_band[0]), float(one_band[1])
+            freq.append(one_band)
+            
+    elif freq_str[0] == '(' and freq_str[-1] == ')':
+        
+        if len(as_list) == 4:
+            start = float(as_list[0])
+            stop = float(as_list[1])
+            halfwidth = float(as_list[2]) / 2
+            step = float(as_list[3])
+            centres = arange(start, stop, step)
+            for i in centres:
+                freq.append((i - halfwidth, i + halfwidth))
+        else:
+            return None
+            
+    else:
+        return None
+    
+    return freq
+    
+    
